docx\_parser\_converter.docx\_parsers.styles package
====================================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   docx_parser_converter.docx_parsers.styles.paragraph_properties_parser
   docx_parser_converter.docx_parsers.styles.run_properties_parser
   docx_parser_converter.docx_parsers.styles.styles_merger
   docx_parser_converter.docx_parsers.styles.styles_parser

Module contents
---------------

.. automodule:: docx_parser_converter.docx_parsers.styles
   :members:
   :undoc-members:
   :show-inheritance:
